=============================
Cell assembly detection (CAD)
=============================

.. automodule:: elephant.cell_assembly_detection


References
----------

.. bibliography::
    :keyprefix: cad-
